pub fn parse_mint_event_hypersync( dex: SharedDex, log: &HypersyncLog, ) -> Result<MintEvent>
Parses a mint event from a HyperSync log.
Returns an error if the log parsing fails or if the event data is invalid.
Panics if the contract address is not set in the log.